@@ -133,7 +133,7 @@ sj_stock_init (void)
   {
     { SJ_STOCK_PLAYING, NULL, 0, 0, NULL },
     { SJ_STOCK_RECORDING, NULL, 0, 0, NULL },
-    { SJ_STOCK_EXTRACT, "E_xtract", GDK_CONTROL_MASK, GDK_Return, NULL }
+    { SJ_STOCK_EXTRACT, N_("E_xtract"), GDK_CONTROL_MASK, GDK_Return, NULL }
   };
 
   if (initialized)
@@ -219,6 +219,7 @@ gboolean poll_tray_opened (gpointer data)
   if (new_status != tray_opened && new_status == FALSE) {
     reread_cd (TRUE);
   } else if (new_status != tray_opened && new_status == TRUE) {
+    stop_ui_hack ();
     update_ui_for_album (NULL);
   }
   tray_opened = new_status;
@@ -1048,7 +1049,8 @@ static GtkTreeModel* create_genre_list(void) {
 GtkWidget *
 sj_make_volume_button (void)
 {
-  GtkWidget *w = bacon_volume_button_new (0.0, 1.0, 0.02);
+  GtkWidget *w = bacon_volume_button_new (GTK_ICON_SIZE_SMALL_TOOLBAR,
+					  0.0, 1.0, 0.02);
   bacon_volume_button_set_value (BACON_VOLUME_BUTTON (w), 1.0);
   return w;
 }
@@ -1086,10 +1088,12 @@ int main (int argc, char **argv)
 {
   GError *error = NULL;
   GtkTreeSelection *selection;
+  char *device = NULL;
   struct poptOption options[] = {
     { NULL, '\0', POPT_ARG_INCLUDE_TABLE, NULL, 0, "GStreamer", NULL },
     { "auto-start", 'a', POPT_ARG_NONE, &autostart, 0, "Start extracting immediately", NULL},
     { "play", 'p', POPT_ARG_NONE, &autoplay, 0, "Start playing immediately", NULL},
+    { "device", 'd', POPT_ARG_STRING, &device, 0, "What CD device to read", NULL},
     POPT_TABLEEND
   };
 
@@ -1266,7 +1270,6 @@ int main (int argc, char **argv)
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 	  
   http_proxy_setup (gconf_client);
-  /* TODO: port port basepath to baseuri */
   baseuri_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_BASEURI, NULL, TRUE, NULL), NULL);
   path_pattern_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_PATH_PATTERN, NULL, TRUE, NULL), NULL);
   file_pattern_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_FILE_PATTERN, NULL, TRUE, NULL), NULL);
@@ -1274,7 +1277,8 @@ int main (int argc, char **argv)
   paranoia_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_PARANOIA, NULL, TRUE, NULL), NULL);
   strip_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_STRIP, NULL, TRUE, NULL), NULL);
   eject_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_EJECT, NULL, TRUE, NULL), NULL);
-  device_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_DEVICE, NULL, TRUE, NULL), GINT_TO_POINTER (TRUE));
+  if (device == NULL)
+    device_changed_cb (gconf_client, -1, gconf_client_get_entry (gconf_client, GCONF_DEVICE, NULL, TRUE, NULL), GINT_TO_POINTER (TRUE));
 
   if (sj_extractor_supports_encoding (&error) == FALSE) {
     error_on_start (error);
